==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-admin/lxqt-admin-user/lxqt-admin-user_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it" sourcelanguage="it_IT">
<context>
    <name>GroupDialog</name>
    <message>
        <location filename="../../../groupdialog.ui" line="14"/>
        <source>Group Settings</source>
        <translation>Impostazioni gruppi</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.ui" line="20"/>
        <source>Group name:</source>
        <translation>Nome del gruppo:</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.ui" line="30"/>
        <source>Default</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../groupdialog.ui" line="40"/>
        <source>Group ID:</source>
        <translation>ID gruppo:</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.ui" line="47"/>
        <source>Users belong to this group:</source>
        <translation>Utenti appartenenti al gruppo:</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.cpp" line="64"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.cpp" line="64"/>
        <source>The group name cannot be empty.</source>
        <translation>Il nome del gruppo non può essere vuoto.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../../mainwindow.ui" line="14"/>
        <source>User and Group Settings</source>
        <translation>Impostazioni utenti e gruppi</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="40"/>
        <source>&amp;Users</source>
        <translatorcomment>remove &amp;_ in source</translatorcomment>
        <translation>&amp;Utenti</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="56"/>
        <source>Login Name</source>
        <translation>Nome di accesso</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="61"/>
        <source>User ID</source>
        <translation>ID utente</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="66"/>
        <source>Full Name</source>
        <translation>Nome completo</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="71"/>
        <source>Group</source>
        <translation>Gruppo</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="76"/>
        <source>Home Directory</source>
        <translation>Cartella Home</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="87"/>
        <source>Show system users (for advanced users only)</source>
        <translation>Mostra utenti di sistema (solo utenti avanzati)</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="95"/>
        <source>&amp;Groups</source>
        <translation>&amp;Gruppi</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="108"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="113"/>
        <source>Group ID</source>
        <translation>ID gruppo</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="118"/>
        <source>Members</source>
        <translation>Membri</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="131"/>
        <source>toolBar</source>
        <translation>Barra degli strumenti</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="158"/>
        <source>Add</source>
        <translation>Aggiungi</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="161"/>
        <source>Add new users or groups</source>
        <translation>Aggiungi nuovi utenti o gruppi</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="170"/>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="173"/>
        <source>Delete selected item</source>
        <translation>Elimina l&apos;elemento selezionato</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="182"/>
        <source>Properties</source>
        <translation>Proprietà</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="185"/>
        <source>edit properties of the selected item</source>
        <translation>modifica le proprietà dell&apos;elemento selezionato</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="194"/>
        <source>Refresh</source>
        <translation>Aggiorna</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="197"/>
        <source>Refresh the lists</source>
        <translation>Aggiorna l&apos;elenco</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="206"/>
        <source>Change Password</source>
        <translation>Cambia password</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="209"/>
        <source>Change password for the selected user or group</source>
        <translation>Cambia password per l&apos;utente o il gruppo selezionato </translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="155"/>
        <location filename="../../../mainwindow.cpp" line="167"/>
        <location filename="../../../mainwindow.cpp" line="188"/>
        <source>Confirm</source>
        <translation>Conferma</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="155"/>
        <source>Are you sure you want to delete the selected user?</source>
        <translation>Si è sicuro di voler eliminare l&apos;utente selezionato?</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="167"/>
        <source>Are you sure you want to delete the selected group?</source>
        <translation>Si è sicuro di voler eliminare il gruppo selezionato?</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="178"/>
        <source>Input the new password for %1:</source>
        <translation>Immetti il nuovo password per %1:</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="188"/>
        <source>Are you sure you want to set a empty password?</source>
        <translation>Si è sicuro ti impostare un password vuoto?</translation>
    </message>
</context>
<context>
    <name>UserDialog</name>
    <message>
        <location filename="../../../userdialog.ui" line="14"/>
        <source>User Settings</source>
        <translation>Impostazioni utente</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="24"/>
        <source>General</source>
        <translation>Generale</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="43"/>
        <source>Full name:</source>
        <translation>Nome completo:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="33"/>
        <source>Login name:</source>
        <translation>Nome di accesso:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="53"/>
        <source>User ID:</source>
        <translation>ID utente:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="60"/>
        <source>Default</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="70"/>
        <source>Main group:</source>
        <translation>Gruppo principale:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="85"/>
        <source>Groups</source>
        <translation>Gruppi</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="91"/>
        <source>The user belongs to the following groups:</source>
        <translation>L&apos;utente appartiene ai seguenti gruppi:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="109"/>
        <source>Advanced</source>
        <translation>Avanzate</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="115"/>
        <source>Login shell:</source>
        <translation>Shell di login:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="132"/>
        <source>Home directory:</source>
        <translation>Cartella Home:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.cpp" line="117"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../../../userdialog.cpp" line="117"/>
        <source>The user name cannot be empty.</source>
        <translation>Il nome non può essere vuoto.</translation>
    </message>
</context>
</TS>

==> lxqt-l10n-0.13.0_p20181121.tar.xz: lxqt-l10n-0.13.0_p20181121/lxqt-admin/lxqt-admin-user/lxqt-admin-user_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it" sourcelanguage="it_IT">
<context>
    <name>GroupDialog</name>
    <message>
        <location filename="../../../groupdialog.ui" line="14"/>
        <source>Group Settings</source>
        <translation>Impostazioni gruppi</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.ui" line="20"/>
        <source>Group name:</source>
        <translation>Nome del gruppo:</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.ui" line="30"/>
        <source>Default</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../groupdialog.ui" line="40"/>
        <source>Group ID:</source>
        <translation>ID gruppo:</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.ui" line="47"/>
        <source>Users belong to this group:</source>
        <translation>Utenti appartenenti al gruppo:</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.cpp" line="64"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.cpp" line="64"/>
        <source>The group name cannot be empty.</source>
        <translation>Il nome del gruppo non può essere vuoto.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../../mainwindow.ui" line="14"/>
        <source>User and Group Settings</source>
        <translation>Impostazioni utenti e gruppi</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="40"/>
        <source>&amp;Users</source>
        <translatorcomment>remove &amp;_ in source</translatorcomment>
        <translation>&amp;Utenti</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="59"/>
        <source>Login Name</source>
        <translation>Nome di accesso</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="64"/>
        <source>User ID</source>
        <translation>ID utente</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="69"/>
        <source>Full Name</source>
        <translation>Nome completo</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="74"/>
        <source>Group</source>
        <translation>Gruppo</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="79"/>
        <source>Home Directory</source>
        <translation>Cartella Home</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="87"/>
        <source>Show system users (for advanced users only)</source>
        <translation>Mostra utenti di sistema (solo utenti avanzati)</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="95"/>
        <source>&amp;Groups</source>
        <translation>&amp;Gruppi</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="111"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="116"/>
        <source>Group ID</source>
        <translation>ID gruppo</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="121"/>
        <source>Members</source>
        <translation>Membri</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="134"/>
        <source>toolBar</source>
        <translation>Barra degli strumenti</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="161"/>
        <source>Add</source>
        <translation>Aggiungi</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="164"/>
        <source>Add new users or groups</source>
        <translation>Aggiungi nuovi utenti o gruppi</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="173"/>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="176"/>
        <source>Delete selected item</source>
        <translation>Elimina l&apos;elemento selezionato</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="185"/>
        <source>Properties</source>
        <translation>Proprietà</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="188"/>
        <source>edit properties of the selected item</source>
        <translation>Modifica le proprietà dell&apos;elemento selezionato</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="197"/>
        <source>Refresh</source>
        <translation>Aggiorna</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="200"/>
        <source>Refresh the lists</source>
        <translation>Aggiorna l&apos;elenco</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="209"/>
        <source>Change Password</source>
        <translation>Cambia password</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="212"/>
        <source>Change password for the selected user or group</source>
        <translation>Cambia password per l&apos;utente o il gruppo selezionato</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="174"/>
        <location filename="../../../mainwindow.cpp" line="186"/>
        <location filename="../../../mainwindow.cpp" line="207"/>
        <source>Confirm</source>
        <translation>Conferma</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="174"/>
        <source>Are you sure you want to delete the selected user?</source>
        <translation>Si è sicuro di voler eliminare l&apos;utente selezionato?</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="186"/>
        <source>Are you sure you want to delete the selected group?</source>
        <translation>Si è sicuro di voler eliminare il gruppo selezionato?</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="197"/>
        <source>Input the new password for %1:</source>
        <translation>Immetti il nuovo password per %1:</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="207"/>
        <source>Are you sure you want to set a empty password?</source>
        <translation>Si è sicuro ti impostare un password vuoto?</translation>
    </message>
</context>
<context>
    <name>UserDialog</name>
    <message>
        <location filename="../../../userdialog.ui" line="14"/>
        <source>User Settings</source>
        <translation>Impostazioni utente</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="24"/>
        <source>General</source>
        <translation>Generale</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="43"/>
        <source>Full name:</source>
        <translation>Nome completo:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="33"/>
        <source>Login name:</source>
        <translation>Nome di accesso:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="53"/>
        <source>User ID:</source>
        <translation>ID utente:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="60"/>
        <source>Default</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="70"/>
        <source>Main group:</source>
        <translation>Gruppo principale:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="85"/>
        <source>Groups</source>
        <translation>Gruppi</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="91"/>
        <source>The user belongs to the following groups:</source>
        <translation>L&apos;utente appartiene ai seguenti gruppi:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="109"/>
        <source>Advanced</source>
        <translation>Avanzate</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="115"/>
        <source>Login shell:</source>
        <translation>Shell di login:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="132"/>
        <source>Home directory:</source>
        <translation>Cartella Home:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.cpp" line="117"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../../../userdialog.cpp" line="117"/>
        <source>The user name cannot be empty.</source>
        <translation>Il nome non può essere vuoto.</translation>
    </message>
</context>
<context>
    <name>UserManager</name>
    <message>
        <location filename="../../../usermanager.cpp" line="224"/>
        <source>lxqt-admin-user</source>
        <translation>Gestione utenti LXQt</translation>
    </message>
    <message>
        <location filename="../../../usermanager.cpp" line="225"/>
        <source>&lt;strong&gt;Action (%1) failed:&lt;/strong&gt;&lt;br/&gt;&lt;pre&gt;%2&lt;/pre&gt;</source>
        <translation>&lt;strong&gt;Azione (%1) fallita:&lt;/strong&gt;&lt;br/&gt;&lt;pre&gt;%2&lt;/pre&gt;</translation>
    </message>
</context>
</TS>
